call japerl.bat xt\0304_FileBasename_fileparse_5C.t
goto END

call japerl.bat xt\0305_FileBasename_basename_5C.t
call japerl.bat xt\0306_FileBasename_dirname_5C.t
call japerl.bat xt\0403_FilePath_mkpath_5C.t
call japerl.bat xt\0404_FilePath_rmtree_5C.t
call japerl.bat xt\0503_FileCopy_copy_5C.t
call japerl.bat xt\0504_FileCopy_move_5C.t
:END
