$::VERSION = $::VERSION = 0.01;
use 5.00503;
use strict;
use Test::Simply tests => 3;
use Stable::Module;

my $dirname = '';

eval {
    $dirname = dirname('/usr/loƒ\al/bin/perl.pl');
};

ok(($dirname eq '/usr/loƒ\al/bin'), qq{dirname('/usr/loƒ\al/bin/perl.pl') $^X @{[__FILE__]}});

eval {
    $dirname = dirname('/usr/lo ƒ\ al/bin/perl.pl');
};

ok(($dirname eq '/usr/lo ƒ\ al/bin'), qq{dirname('/usr/lo ƒ\ al/bin/perl.pl') $^X @{[__FILE__]}});

eval {
    $dirname = dirname('/usr/lo ƒ\ al/bin/pƒ\rl.pl');
};

ok(($dirname eq '/usr/lo ƒ\ al/bin'), qq{dirname('/usr/lo ƒ\ al/bin/pƒ\rl.pl') $^X @{[__FILE__]}});

__END__
